Prolog
======

Django-auth-token is library that improved Django framework with token authorization.
Tokens are randomly generated strings which are stored inside database with some information about user
like IP address, user agent, etc. Every token expires automatically according to Django-token-authorization settings.
Advantage is the possibility of deactivation of the token or retrieving the permissions of another user.

Installation
------------

.. code:: bash

    pip install django-auth-token


Docs
----

For more details see [docs](http://django-auth-token.readthedocs.org/)
